This is version 1.2. The object contains valid returns of GWS v1.0.0, as of 2025-03-14.
data(gws)A data.frame with 5 variables and 26 observations.
The valid return combinations for selected models and feature collections are copied from https://gwsdoc.gplates.org/models.
modelThe name of the reconstruction model.
featureThe name of the feature collection.
fromThe oldest reconstruction age accepted by the model to return the feature collection.
toThe youngest reconstruction age accepted by the model to return the feature collection.
descriptionThe short description of the feature collection.