An eye-candy utility function for 3d-effect of global maps
Usage
sphereshade(
n = 180,
left = "#ffffff",
right = "#aaaaaa",
crs = "EPSG:4326",
left.alpha = 1,
right.alpha = 1,
west = -180,
east = 180
)Arguments
- n
The number of color bands.
- left
RGB color for the left side of the gradient.
- right
RGB color for the right side of the gradient.
- crs
A coordinate reference system string to be passed to
mapedge.- left.alpha
The alpha value (0-1) used for the left side of the plot.
- right.alpha
The alpha value (0-1) used for the right side of the plot.
- west
The
xminargument ofmapedge.- east
The
xmaxargument ofmapedge.